==> blueprintjs__datetime-1.0.1.jar: META-INF/resources/webjars/blueprintjs__datetime/1.0.1/src/common/classes.ts <==
/*
 * Copyright 2015 Palantir Technologies, Inc. All rights reserved.
 * Licensed under the Apache License, Version 2.0 - http://www.apache.org/licenses/LICENSE-2.0
 */

export const DATEPICKER = "pt-datepicker";
export const DATEPICKER_CAPTION = "pt-datepicker-caption";
export const DATEPICKER_CAPTION_CARET = "pt-datepicker-caption-caret";
export const DATEPICKER_CAPTION_SELECT = "pt-datepicker-caption-select";
export const DATEPICKER_DAY = "DayPicker-Day";
export const DATEPICKER_DAY_DISABLED = "DayPicker-Day--disabled";
export const DATEPICKER_DAY_OUTSIDE = "DayPicker-Day--outside";
export const DATEPICKER_DAY_SELECTED = "DayPicker-Day--selected";
export const DATEPICKER_FOOTER = "pt-datepicker-footer";
export const DATEPICKER_MONTH_SELECT = "pt-datepicker-month-select";
export const DATEPICKER_YEAR_SELECT = "pt-datepicker-year-select";

export const DATERANGEPICKER = "pt-daterangepicker";
export const DATERANGEPICKER_DAY_SELECTED_RANGE = "DayPicker-Day--selected-range";
export const DATERANGEPICKER_SHORTCUTS = "pt-daterangepicker-shortcuts";

export const DATETIMEPICKER = "pt-datetimepicker";

export const TIMEPICKER = "pt-timepicker";
export const TIMEPICKER_ARROW_BUTTON = "pt-timepicker-arrow-button";
export const TIMEPICKER_ARROW_ROW = "pt-timepicker-arrow-row";
export const TIMEPICKER_DIVIDER_TEXT = "pt-timepicker-divider-text";
export const TIMEPICKER_HOUR = "pt-timepicker-hour";
export const TIMEPICKER_INPUT = "pt-timepicker-input";
export const TIMEPICKER_INPUT_ROW = "pt-timepicker-input-row";
export const TIMEPICKER_MILLISECOND = "pt-timepicker-millisecond";
export const TIMEPICKER_MINUTE = "pt-timepicker-minute";
export const TIMEPICKER_SECOND = "pt-timepicker-second";

==> blueprintjs__datetime-1.22.0.jar: META-INF/resources/webjars/blueprintjs__datetime/1.22.0/src/common/classes.ts <==
/*
 * Copyright 2015 Palantir Technologies, Inc. All rights reserved.
 * Licensed under the BSD-3 License as modified (the “License”); you may obtain a copy
 * of the license at https://github.com/palantir/blueprint/blob/master/LICENSE
 * and https://github.com/palantir/blueprint/blob/master/PATENTS
 */

export const DATEPICKER = "pt-datepicker";
export const DATEPICKER_CAPTION = "pt-datepicker-caption";
export const DATEPICKER_CAPTION_CARET = "pt-datepicker-caption-caret";
export const DATEPICKER_CAPTION_SELECT = "pt-datepicker-caption-select";
export const DATEPICKER_DAY = "DayPicker-Day";
export const DATEPICKER_DAY_DISABLED = "DayPicker-Day--disabled";
export const DATEPICKER_DAY_OUTSIDE = "DayPicker-Day--outside";
export const DATEPICKER_DAY_SELECTED = "DayPicker-Day--selected";
export const DATEPICKER_FOOTER = "pt-datepicker-footer";
export const DATEPICKER_MONTH_SELECT = "pt-datepicker-month-select";
export const DATEPICKER_YEAR_SELECT = "pt-datepicker-year-select";

export const DATERANGEPICKER = "pt-daterangepicker";
export const DATERANGEPICKER_CONTIGUOUS = "pt-daterangepicker-contiguous";
export const DATERANGEPICKER_SINGLE_MONTH = "pt-daterangepicker-single-month";
export const DATERANGEPICKER_DAY_SELECTED_RANGE = "DayPicker-Day--selected-range";
export const DATERANGEPICKER_DAY_HOVERED_RANGE = "DayPicker-Day--hovered-range";
export const DATERANGEPICKER_SHORTCUTS = "pt-daterangepicker-shortcuts";

export const DATETIMEPICKER = "pt-datetimepicker";

export const TIMEPICKER = "pt-timepicker";
export const TIMEPICKER_ARROW_BUTTON = "pt-timepicker-arrow-button";
export const TIMEPICKER_ARROW_ROW = "pt-timepicker-arrow-row";
export const TIMEPICKER_DIVIDER_TEXT = "pt-timepicker-divider-text";
export const TIMEPICKER_HOUR = "pt-timepicker-hour";
export const TIMEPICKER_INPUT = "pt-timepicker-input";
export const TIMEPICKER_INPUT_ROW = "pt-timepicker-input-row";
export const TIMEPICKER_MILLISECOND = "pt-timepicker-millisecond";
export const TIMEPICKER_MINUTE = "pt-timepicker-minute";
export const TIMEPICKER_SECOND = "pt-timepicker-second";
